pygeodesy.units

Package pygeodesy :: Module units |
[frames] | no frames]

# Module units

Various named units, all sub-classes of `Float`, `Int` or `Str` from basic `float`, `int` respectively `str` to named units as Degrees, Feet, Meter, Radians, etc.

Version: 25.05.12

Classes
| _NamedUnit (INTERNAL) Base class for `units`.
| Float_ Named `float` with optional `low` and `high` limit.
| Int_ Named `int` with optional limits `low` and `high`.
| Bool Named `bool`, a sub-class of `int` like Python's `bool`.
| Band Named `str` representing a UTM/UPS band letter, unchecked.
| Degrees Named `float` representing a coordinate in `degrees`, optionally clipped.
| Degrees_ Named `Degrees` representing a coordinate in `degrees` with optional limits `low` and `high`.
| Degrees2 Named `float` representing a distance in `degrees squared`.
| Radians Named `float` representing a coordinate in `radians`, optionally clipped.
| Radians_ Named `float` representing a coordinate in `radians` with optional limits `low` and `high`.
| Radians2 Named `float` representing a distance in `radians squared`.
| Azimuth Named `float` representing an azimuth in compass `degrees` from (true) North.
| Bearing Named `float` representing a bearing in compass `degrees` from (true) North.
| Bearing_ Named `float` representing a bearing in `radians` from compass `degrees` from (true) North.
| Distance Named `float` representing a distance, conventionally in `meter`.
| Distance_ Named `float` with optional `low` and `high` limits representing a distance, conventionally in `meter`.
| Easting Named `float` representing an easting, conventionally in `meter`.
| Epoch Named `epoch` with optional `low` and `high` limits representing a fractional calendar year.
| Feet Named `float` representing a distance or length in `feet`.
| FIx A named Fractional Index, an `int` or `float` index into a `list` or `tuple` of `points`, typically.
| Height Named `float` representing a height, conventionally in `meter`.
| Height_ Named `float` with optional `low` and `high` limits representing a height, conventionally in `meter`.
| HeightX Like Height, used to distinguish the interpolated height from an original Height at a clip intersection.
| Lam Named `float` representing a longitude in `radians`.
| Lamd Named `float` representing a longitude in `radians` converted from `degrees`.
| Lat Named `float` representing a latitude in `degrees`.
| Lat_ Named `float` representing a latitude in `degrees` within limits `low` and `high`.
| Lon Named `float` representing a longitude in `degrees`.
| Lon_ Named `float` representing a longitude in `degrees` within limits `low` and `high`.
| Meter Named `float` representing a distance or length in `meter`.
| Meter_ Named `float` representing a distance or length in `meter`.
| Meter2 Named `float` representing an area in `meter squared`.
| Meter3 Named `float` representing a volume in `meter cubed`.
| Northing Named `float` representing a northing, conventionally in `meter`.
| Number_ Named `int` representing a non-negative number.
| Phi Named `float` representing a latitude in `radians`.
| Phid Named `float` representing a latitude in `radians` converted from `degrees`.
| Precision_ Named `int` with optional `low` and `high` limits representing a precision.
| Radius_ Named `float` with optional `low` and `high` limits representing a radius, conventionally in `meter`.
| Scalar Named `float` representing a factor, fraction, scale, etc.
| Scalar_ Named `float` with optional `low` and `high` limits representing a factor, fraction, scale, etc.
| Zone Named `int` representing a UTM/UPS zone number.

Variables
| __all__ = `_ALL_LAZY.units`